import setuptools

setuptools.setup(
    name="DividenderX",
    version="0.0.5",
    author="Xavier Navarro",
    description="Gives you a close estimate of how much your dividend payer asset will grow overtime. ",
    packages=['Dividender'],
    classifiers =[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)",
        "Operating System :: OS Independent",
        ],
    long_description_content_type="text/markdown"

)
